import 'package:flutter/material.dart';
import 'package:chapa/core/chapa_error.dart';
import 'package:chapa/models/responses/charge_response.dart';
import 'package:chapa/utils/chapa_currency.dart';
import 'package:chapa/widgets/home/chapa_payment.dart';

import 'chapa_payment_manager.dart';

class Chapa {
  BuildContext context;
  String publicKey;
  String encryptionKey;
  bool isDebugMode;
  String amount;
  String currency;
  String email;
  String fullName;
  String txRef;
  String redirectUrl;
  bool acceptCardPayment;
  String phoneNumber;
  int? frequency;
  int duration;
  bool isPermanent;
  String narration;
  String? country;


  /// Chapa Constructor
  Chapa.forUIPayment({
    required this.context,
    required this.publicKey,
    required this.encryptionKey,
    required this.currency,
    required this.amount,
    required this.email,
    required this.fullName,
    required this.txRef,
    required this.isDebugMode,
    required this.phoneNumber,
    this.frequency,
    this.duration = 0,
    this.isPermanent = false,
    this.narration = "",
    this.acceptCardPayment = false,
    this.redirectUrl = ""

  }) {
    _validateKeys();
    this.currency = this.currency.toUpperCase();
    _setPaymentTypes();
  }

  void _setPaymentTypes() {



    // if (this.currency == ChapaCurrency.ETB) {
    //   this.acceptTelebirr = false;

    //   return;
    // }

    this.acceptCardPayment = true;

    return;
  }

String _setCountry() {
  switch (this.currency) {
  //TODO to be included once ACH payment is available on v1
    case ChapaCurrency.ETB:
      return "ET";
    case ChapaCurrency.USD:
      return "US";
  }
}


/// Launches payment screen
/// Returns a future ChargeResponse intance
/// Nullable
Future<ChargeResponse> initializeForUiPayments() async {
  ChapaPaymentManager paymentManager = ChapaPaymentManager(
      publicKey: this.publicKey,
      encryptionKey: this.encryptionKey,
      currency: this.currency,
      email: this.email,
      fullName: this.fullName,
      amount: this.amount,
      txRef: this.txRef,
      isDebugMode: this.isDebugMode,
      narration: this.narration,
      isPermanent: this.isPermanent,
      phoneNumber: this.phoneNumber,
      frequency: this.frequency,
      duration: this.duration,
      redirectUrl: this.redirectUrl,
      acceptCardPayment: this.acceptCardPayment,

      country: this._setCountry());

  final chargeResponse = await this._launchPaymentScreen(paymentManager);
  return chargeResponse;
}

Future<ChargeResponse> _launchPaymentScreen(
    final ChapaPaymentManager paymentManager) async {
  return await Navigator.push(
    this.context,
    MaterialPageRoute(builder: (context) => ChapaUI(paymentManager)),
  );
}

void _validateKeys() {
  if (this.encryptionKey
      .trim()
      .isEmpty) throw ChApaError("Encrytion key is required");
  if (this.publicKey
      .trim()
      .isEmpty) throw ChApaError("Public key is required");
  if (this.currency
      .trim()
      .isEmpty) throw ChApaError("Currency is required");
  if (this.amount
      .trim()
      .isEmpty) throw ChApaError("Amount is required");
  if (this.email
      .trim()
      .isEmpty) throw ChApaError("Email is required");
  if (this.fullName
      .trim()
      .isEmpty) throw ChApaError("Full Name is required");
  if (this.txRef
      .trim()
      .isEmpty) throw ChApaError("txRef is required");
  if (this.phoneNumber
      .trim()
      .isEmpty) throw ChApaError("Phone Number is required");
}}
