import 'package:flutter/material.dart';
import 'package:chapa/core/card_payment_manager/card_payment_manager.dart';
import 'package:chapa/core/chapa_payment_manager.dart';
import 'package:chapa/models/responses/charge_response.dart';
import 'package:chapa/widgets/card_payment/card_payment.dart';


import 'chapa_payment_option.dart';

class ChapaUI extends StatefulWidget {
  final ChapaPaymentManager _chapaPaymentManager;

  ChapaUI(this._chapaPaymentManager);

  @override
  _ChapaUIState createState() => _ChapaUIState();
}

class _ChapaUIState extends State<ChapaUI> {
  final GlobalKey<ScaffoldState> _scaffoldKey = GlobalKey<ScaffoldState>();

  @override
  Widget build(BuildContext context) {
    final ChapaPaymentManager paymentManager =
        this.widget._chapaPaymentManager;

    return MaterialApp(
      debugShowCheckedModeBanner: paymentManager.isDebugMode,
      theme: ThemeData(fontFamily: "CHP"),
      home: Scaffold(
        key: this._scaffoldKey,
        body: SingleChildScrollView(
          child: ConstrainedBox(
            constraints: BoxConstraints(
              maxHeight: MediaQuery.of(context).size.height,
            ),
            child: SafeArea(
              child: Container(
                width: double.infinity,
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    Container(
                      margin: EdgeInsets.fromLTRB(10, 50, 10, 70),
                      child: Column(
                        children: [
                          Row(
                            mainAxisSize: MainAxisSize.max,
                            children: [
                              Icon(
                                Icons.lock,
                                size: 10.0,
                                color: Colors.black,
                              ),
                              SizedBox(
                                width: 5.0,
                              ),
                              Text(
                                "SECURED BY CHAPA",
                                style: TextStyle(
                                    color: Colors.black,
                                    fontSize: 10.0,
                                    fontFamily: "CHP",
                                    letterSpacing: 1.0),
                              )
                            ],
                          ),
                          SizedBox(
                            width: double.infinity,
                            height: 100,
                          ),
                          Container(
                            width: double.infinity,
                            margin: EdgeInsets.fromLTRB(0, 100, 0, 0),
                            child: Text(
                              "How would you \nlike to pay?",
                              textAlign: TextAlign.left,
                              style: TextStyle(
                                fontWeight: FontWeight.bold,
                                color: Colors.black,
                                fontFamily: "CHP",
                                fontSize: 30.0,
                              ),
                            ),
                          ),
                          Align(
                            alignment: Alignment.centerLeft,
                            child: Container(
                              height: 5,
                              width: 200,
                              color: Colors.pink,
                              margin: EdgeInsets.fromLTRB(0, 20, 0, 10),
                            ),
                          ),
                        ],
                      ),
                    ),
                    Container(
                      color: Colors.white38,
                      width: double.infinity,
                      child: Column(
                        children: [
                          Visibility(
                            visible: paymentManager.acceptCardPayment,
                            child: Column(
                              children: [
                                SizedBox(
                                  width: double.infinity,
                                  height: 50.0,
                                  child: ChapaPaymentOption(
                                    handleClick: this._launchCardPaymentWidget,
                                    buttonText: "Card",
                                  ),
                                ),
                                SizedBox(
                                  height: 0.5,
                                ),
                              ],
                            ),
                          )
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }

  void _launchCardPaymentWidget() async {
    final CardPaymentManager cardPaymentManager =
        this.widget._chapaPaymentManager.getCardPaymentManager();

    final dynamic response = await Navigator.push(
      this.context,
      MaterialPageRoute(builder: (context) => CardPayment(cardPaymentManager)),
    );
    _handleBackPress(response);
  }



  void showSnackBar(String message) {
    SnackBar snackBar = SnackBar(
      content: Text(
        message,
        textAlign: TextAlign.center,
      ),
    );
    this._scaffoldKey.currentState!.showSnackBar(snackBar);
  }

  void _handleBackPress(dynamic result) {
    if (result == null || result is ChargeResponse){
      final ChargeResponse? chargeResponse = result as ChargeResponse;
      String message;
      if (chargeResponse != null) {
        message = chargeResponse.message!;
      } else {
        message = "Transaction cancelled";
      }
      this.showSnackBar(message);
      Navigator.pop(this.context, chargeResponse);
    } else {
      // checking if back arrow was pressed so we do nothing.
    }
  }
}
